<?php
/**
 * Class WFSPB_FrontEnd
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit();
}

class WFSPB_FrontEnd {
	protected $settings;

	public function __construct() {
		$this->settings = new WFSPB_Data();
		if ( $this->settings->get_option( 'enable' ) ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_script_fontend' ), 899999 );
			add_action( 'wp_footer', array( $this, 'show_bar_conditional' ), 90 );

			/*Single product page*/
			add_action( 'woocommerce_after_add_to_cart_button', array( $this, 'show_bar_bottom' ) );
			/*Cart page*/
			switch ( $this->settings->get_option( 'position_cart' ) ) {
				case 0:
					/*Above Process Button*/
					add_action( 'woocommerce_proceed_to_checkout', array( $this, 'show_bar_bottom' ) );
					break;
				default:
					/*Below Process Button*/
					add_action( 'woocommerce_after_cart_totals', array( $this, 'show_bar_bottom' ) );
			}


			/*Checkout page*/
			switch ( $this->settings->get_option( 'position_checkout' ) ) {
				case 0:
					/*Before payment methods*/
					add_action( 'woocommerce_review_order_before_payment', array( $this, 'show_bar_bottom' ) );

					break;
				default:
					/*Below Process Button*/
					add_action( 'woocommerce_checkout_order_review', array( $this, 'show_bar_bottom' ), 30 );
			}
			add_filter( 'woocommerce_update_order_review_fragments', array( $this, 'befor_payment_methods' ) );
		}

	}

	public function befor_payment_methods( $data ) {
		$html                                         = $this->get_small_bar_ajax_html();
		$data['.woocommerce-free-shipping-bar-order'] = '<div class="woocommerce-free-shipping-bar-order">' . $html . '</div>';

		return $data;
	}

	private function get_small_bar_ajax_html() {
		ob_start();
		/*Get settings*/
		$message_error = $this->get_message( 'message-error' );
		$default_zone  = $this->settings->get_option( 'default-zone' );
		$shopping      = '<a class="wfsb-link" href="' . get_permalink( get_option( 'woocommerce_shop_page_id' ) ) . '">' . __( 'Shopping', 'woocommerce-free-shipping-bar' ) . '</a>';

		/*Get min amount*/
		$customer = WC()->session->get( 'customer' );
		$country  = isset( $customer['shipping_country'] ) ? $customer['shipping_country'] : '';
		$state    = isset( $customer['shipping_state'] ) ? $customer['shipping_state'] : '';
		$postcode = isset( $customer['shipping_postcode'] ) ? $customer['shipping_postcode'] : '';
		if ( $country ) {
			$order_min_amount = $this->settings->detect_ip( $country, $state, $postcode );
		} else if ( $this->settings->get_option( 'detect-ip' ) ) {
			$order_min_amount = $this->settings->detect_ip();
		} elseif ( $default_zone ) {
			$order_min_amount = $this->settings->get_min_amount( $default_zone );
		} else {
			$order_min_amount = $this->settings->get_shipping_min_amount();
		}
		if ( ! $order_min_amount ) {
			return '';
		}
		// get value current total cart
		$total = WC()->cart->get_displayed_subtotal();
		if ( WC()->cart->display_prices_including_tax() ) {
			$total = round( $total - ( WC()->cart->get_discount_total() + WC()->cart->get_discount_tax() ), wc_get_price_decimals() );
		} else {
			$total = round( $total - WC()->cart->get_discount_total(), wc_get_price_decimals() );
		}
		$key_msgerror = array(
			'{missing_amount}',
			'{shopping}'
		);
		if ( $total < $order_min_amount ) {
			$missing_amount   = $order_min_amount - $total;
			$missing_amount_r = $missing_amount;
			if ( is_cart() || is_checkout() ) {
				if ( ! wc()->cart->display_prices_including_tax() ) {
					if ( 'incl' !== get_option( 'woocommerce_tax_display_shop' ) && ! wc_prices_include_tax() ) {
						$missing_amount_r = $this->settings->real_amount( $missing_amount );
					}


				}
			} else {
				if ( 'incl' === get_option( 'woocommerce_tax_display_shop' ) ) {
					if ( ! wc()->cart->display_prices_including_tax() ) {
						$missing_amount_r = $this->settings->get_price_including_tax( $missing_amount );
					}

				} else {
					if ( ! wc_prices_include_tax() ) {
						$missing_amount_r = $this->settings->real_amount( $missing_amount );
					}

				}
			}
			?>
            <div class="woocommerce-free-shipping-bar-order-content">
                <div class="woocommerce-free-shipping-bar-order-content">
					<?php
					$msgerror_replaced = array(
						'<strong>' . wc_price( $missing_amount_r ) . '</strong>',
						$shopping
					);
					$message           = str_replace( $key_msgerror, $msgerror_replaced, strip_tags( $message_error ) );
					echo $message;

					/*Bar progress*/
					$width = round( ( $total / $order_min_amount * 100 ), 0 )
					?>
                </div>
                <div class="woocommerce-free-shipping-bar-order-bar">
                    <div class="woocommerce-free-shipping-bar-order-bar-inner"
                         style="width: <?php echo esc_attr( $width ) ?>%">
                    </div>
                </div>
            </div>
		<?php }

		return ob_get_clean();
	}

	/**
	 * Show bar at bottom
	 */
	public function show_bar_bottom() {
		if ( ( is_checkout() || is_cart() || ( is_single() && $this->settings->get_option( 'show_single_product' ) ) ) && $this->settings->get_option( 'show_at_order_bottom' ) ) {

			$conditional_tags = $this->settings->get_option( 'conditional-tags' );
			$detect_mobile    = $this->settings->get_option( 'detect-mobile' );
			$agn_cart         = $this->settings->get_option( 'agn-cart' );
			$agn_checkout     = $this->settings->get_option( 'agn-checkout' );

			// Detect display on mobile or not
			$detect_mb = new WFSPB_Mobile_Detect();
			if ( $detect_mb->isMobile() ) {
				if ( $detect_mobile == 0 ) {
					return false;
				}
			}

			if ( $conditional_tags ) {
				if ( stristr( $conditional_tags, "return" ) === false ) {
					$conditional_tags = "return (" . $conditional_tags . ");";
				}
				if ( eval( $conditional_tags ) ) {
					return;
				}
			}
			if ( $agn_cart ) {
				if ( is_cart() ) {
					return;
				}
			}

			if ( $agn_checkout ) {
				if ( is_checkout() ) {
					return;
				}
			}
			/*Get settings*/
			$message_error = $this->get_message( 'message-error' );
			$default_zone  = $this->settings->get_option( 'default-zone' );
			$shopping      = '<a class="wfsb-link" href="' . get_permalink( get_option( 'woocommerce_shop_page_id' ) ) . '">' . __( 'Shopping', 'woocommerce-free-shipping-bar' ) . '</a>';
			// get value current total cart
			$total = WC()->cart->get_displayed_subtotal();

			if ( WC()->cart->display_prices_including_tax() ) {
				$total = round( $total - ( WC()->cart->get_discount_total() + WC()->cart->get_discount_tax() ), wc_get_price_decimals() );
			} else {
				$total = round( $total - WC()->cart->get_discount_total(), wc_get_price_decimals() );
			}

			/*Get min amount*/
			$customer = WC()->session->get( 'customer' );
			$country  = isset( $customer['shipping_country'] ) ? $customer['shipping_country'] : '';
			$state    = isset( $customer['shipping_state'] ) ? $customer['shipping_state'] : '';
			$postcode = isset( $customer['shipping_postcode'] ) ? $customer['shipping_postcode'] : '';
			if ( $country ) {
				$order_min_amount = $this->settings->detect_ip( $country, $state, $postcode );
			} else if ( $this->settings->get_option( 'detect-ip' ) ) {
				$order_min_amount = $this->settings->detect_ip();
			} elseif ( $default_zone ) {
				$order_min_amount = $this->settings->get_min_amount( $default_zone );
			} else {
				$order_min_amount = $this->settings->get_shipping_min_amount();
			}
			if ( ! $order_min_amount ) {
				if ( is_checkout() ) {
					?>
                    <div class="woocommerce-free-shipping-bar-order"></div>
					<?php
				}

				return;
			}
			$key_msgerror = array(
				'{missing_amount}',
				'{shopping}'
			);
			if ( $total < $order_min_amount ) {
				?>
                <div class="woocommerce-free-shipping-bar-order">
                    <div class="woocommerce-free-shipping-bar-order-content">
                        <div class="woocommerce-free-shipping-bar-order-content">
							<?php
							$missing_amount   = $order_min_amount - $total;
							$missing_amount_r = $missing_amount;

							if ( is_cart() || is_checkout() ) {
								if ( ! wc()->cart->display_prices_including_tax() ) {

									if ( 'incl' !== get_option( 'woocommerce_tax_display_shop' ) && ! wc_prices_include_tax() ) {

										$missing_amount_r = $this->settings->real_amount( $missing_amount );
									}


								}
							} else {
								if ( 'incl' === get_option( 'woocommerce_tax_display_shop' ) ) {
									if ( ! wc()->cart->display_prices_including_tax() ) {

										$missing_amount_r = $this->settings->get_price_including_tax( $missing_amount );
									}

								} else {
									if ( ! wc_prices_include_tax() ) {

										$missing_amount_r = $this->settings->real_amount( $missing_amount );
									}

								}
							}

							$msgerror_replaced = array(
								'<strong>' . wc_price( $missing_amount_r ) . '</strong>',
								$shopping
							);
							$message           = str_replace( $key_msgerror, $msgerror_replaced, strip_tags( $message_error ) );
							echo $message;

							/*Bar progress*/
							$width = round( ( $total / $order_min_amount * 100 ), 0 )
							?>
                        </div>
                        <div class="woocommerce-free-shipping-bar-order-bar">
                            <div class="woocommerce-free-shipping-bar-order-bar-inner"
                                 style="width: <?php echo esc_attr( $width ) ?>%">
                            </div>
                        </div>
                    </div>
                </div>
			<?php }

		}
		?>

	<?php }

	/**
	 * Init Script
	 */
	public function enqueue_script_fontend() {
		$params               = $this->settings;
		$conditional_tags     = $params->get_option( 'conditional-tags' );
		$agn_homepage         = $params->get_option( 'agn-homepage' );
		$agn_cart             = $params->get_option( 'agn-cart' );
		$agn_shop             = $params->get_option( 'agn-shop' );
		$agn_checkout         = $params->get_option( 'agn-checkout' );
		$agn_single_product   = $params->get_option( 'agn-single-product' );
		$agn_product_category = $params->get_option( 'agn-product-category' );
		$agn_product_tag      = $params->get_option( 'agn-product-tag' );
		if ( ( is_checkout() || is_cart() ) && $this->settings->get_option( 'show_at_order_bottom' ) ) {

		} else {
			if ( $agn_homepage ) {
				if ( is_front_page() ) {
					return;
				}

			}

			if ( $agn_cart ) {
				if ( is_cart() ) {
					return;
				}
			}

			if ( $agn_shop ) {
				if ( is_shop() ) {
					return;
				}
			}

			if ( $agn_checkout ) {
				if ( is_checkout() ) {
					return;
				}
			}

			if ( $agn_single_product ) {
				if ( is_product() ) {
					return;
				}
			}

			if ( $agn_product_category ) {
				if ( is_product_category() ) {
					return;
				}
			}

			if ( $agn_product_tag ) {
				if ( is_product_tag() ) {
					return;
				}
			}

			if ( $conditional_tags ) {
				if ( stristr( $conditional_tags, "return" ) === false ) {
					$conditional_tags = "return (" . $conditional_tags . ");";
				}
				if ( eval( $conditional_tags ) ) {
					return;
				}

			}
		}
		if ( $params->check_woo_shipping_zone() ) {
			wp_enqueue_style( 'woocommerce-free-shipping-bar', plugins_url( 'woocommerce-free-shipping-bar/assets/css/woocommerce-free-shipping-bar-frontend-style.css', 'woocommerce-free-shipping-bar' ) );
			if ( defined( WP_CACHE ) && WP_CACHE ) {
				wp_enqueue_script( 'woocommerce-free-shipping-bar-cache', plugins_url( 'woocommerce-free-shipping-bar/assets/js/woocommerce-free-shipping-bar-cache.js' ), array( 'jquery' ), WFSPB_VERSION, true );
			}
			wp_enqueue_script( 'woocommerce-free-shipping-bar', plugins_url( 'woocommerce-free-shipping-bar/assets/js/woocommerce-free-shipping-bar-frontend.js' ), array( 'jquery' ), WFSPB_VERSION, true );

			$bg_color        = $params->get_option( 'bg-color' );
			$text_color      = $params->get_option( 'text-color' );
			$link_color      = $params->get_option( 'link-color' );
			$text_align      = $params->get_option( 'text-align' );
			$font            = $params->get_option( 'font' );
			$font_size       = $params->get_option( 'font-size' );
			$enable_progress = $params->get_option( 'enable-progress' );
			$style           = $params->get_option( 'style' );
			if ( $font == 'Default' ) {
				$font = '';
			}
			if ( ! empty( $font ) ) {
				$font = str_replace( '+', ' ', $font );
				wp_enqueue_style( 'google-font-' . strtolower( $font ), '//fonts.googleapis.com/css?family=' . $font . ':400,700' );
			}

			switch ( $style ) {
				case 2:
					wp_enqueue_style( 'woocommerce-free-shipping-bar-style2', plugins_url( 'woocommerce-free-shipping-bar/assets/css/style-progress/style2.css', 'woocommerce-free-shipping-bar' ) );
					$css_style2 = "
						#wfspb-top-bar #wfspb-progress::before, #wfspb-top-bar #wfspb-progress::after{
							border-bottom-color: {$bg_color} !important;
						}
					";
					wp_add_inline_style( 'woocommerce-free-shipping-bar-style2', $css_style2 );
					break;
				case 3:
					wp_enqueue_style( 'woocommerce-free-shipping-bar-style3', plugins_url( 'woocommerce-free-shipping-bar/assets/css/style-progress/style3.css', 'woocommerce-free-shipping-bar' ) );
					break;
				default :
					wp_enqueue_style( 'woocommerce-free-shipping-bar-style', plugins_url( 'woocommerce-free-shipping-bar/assets/css/style-progress/style.css', 'woocommerce-free-shipping-bar' ) );
					break;
			}


			$custom_css = "
				#wfspb-top-bar{
					background-color: {$bg_color} !important;
					color: {$text_color} !important;
				} 
				#wfspb-top-bar{
					text-align: {$text_align} !important;
				}
				#wfspb-top-bar > #wfspb-main-content{
					padding: 0 " . ( $font_size * 2 ) . "px;
					font-size: {$font_size}px !important;
					text-align: {$text_align} !important;
					color: {$text_color} !important;
				}
				#wfspb-top-bar > #wfspb-main-content > a,#wfspb-top-bar > #wfspb-main-content b, #wfspb-top-bar > #wfspb-main-content b span{
					color: {$link_color} !important;
				}
				div#wfspb-close{
				font-size: {$font_size}px !important;
				line-height: {$font_size}px !important;
				}
				";
			if ( $font ) {
				$custom_css .= "
				#wfspb-top-bar{
					font-family: {$font} !important;
				}";
			}
			if ( $enable_progress ) {
				$detect_ip           = $params->get_option( 'detect-ip' );
				$default_zone        = $params->get_option( 'default-zone' );
				$bg_progress         = $params->get_option( 'bg-color-progress' );
				$bg_current_progress = $params->get_option( 'bg-current-progress' );
				$progress_text_color = $params->get_option( 'progress-text-color' );
				$fontsize_progress   = $params->get_option( 'font-size-progress' );

				$customer = WC()->session->get( 'customer' );
				$country  = isset( $customer['shipping_country'] ) ? $customer['shipping_country'] : '';
				$state    = isset( $customer['shipping_state'] ) ? $customer['shipping_state'] : '';

				$postcode = isset( $customer['shipping_postcode'] ) ? $customer['shipping_postcode'] : '';
				if ( $country ) {
					$min_amount = $params->detect_ip( $country, $state, $postcode );
				} else if ( $detect_ip ) {
					$min_amount = $params->detect_ip();

				} elseif ( $default_zone ) {
					$min_amount = $params->get_min_amount( $default_zone );
				} else {
					$min_amount = $params->get_shipping_min_amount();
				}
				$total = WC()->cart->get_displayed_subtotal();

				if ( WC()->cart->display_prices_including_tax() ) {
					$total = round( $total - ( WC()->cart->get_discount_total() + WC()->cart->get_discount_tax() ), wc_get_price_decimals() );
				} else {
					$total = round( $total - WC()->cart->get_discount_total(), wc_get_price_decimals() );
				}

				if ( $total >= $min_amount ) {
					$custom_css .= "
							#wfspb-current-progress{ width: 100%; }
						";
				} else {
					if ( $min_amount == 0 ) {
						$amount_total_pr = $total * 100;
					} else {
						$amount_total_pr = round( ( $total * 100 ) / $min_amount, 2 );
					}
					$custom_css .= "
						#wfspb-current-progress{
							width: {$amount_total_pr}%;
						}";
				}
				$custom_css .= "
					#wfspb-progress,.woocommerce-free-shipping-bar-order .woocommerce-free-shipping-bar-order-bar{
						background-color: {$bg_progress} !important;
					}
					#wfspb-current-progress,.woocommerce-free-shipping-bar-order .woocommerce-free-shipping-bar-order-bar .woocommerce-free-shipping-bar-order-bar-inner{
						background-color: {$bg_current_progress} !important;
					}
					#wfspb-top-bar > #wfspb-progress.wfsb-effect-2{
					outline-color:{$bg_current_progress} !important;
					}
					#wfspb-label{
						color: {$progress_text_color} !important;
						font-size: {$fontsize_progress}px !important;
					}
				";
			}
			$css = $params->get_option( 'custom_css' );

			wp_add_inline_style( 'woocommerce-free-shipping-bar', $custom_css . $css );
			// Localize the script with new data
			$translation_array = array(
				'ajax_url'  => admin_url( 'admin-ajax.php' ),
				'lang_code' => function_exists( 'wpml_get_current_language' ) ? wpml_get_current_language() : 'default',
                'time_to_disappear'=>boolval($params->get_option('time-to-disappear')),
			);
			wp_localize_script( 'woocommerce-free-shipping-bar', '_wfsb_params', $translation_array );
		}
	}

	public function show_bar_conditional() {
		$params = $this->settings;
		if ( ! is_admin() ) {
			$conditional_tags     = $params->get_option( 'conditional-tags' );
			$agn_homepage         = $params->get_option( 'agn-homepage' );
			$agn_cart             = $params->get_option( 'agn-cart' );
			$agn_shop             = $params->get_option( 'agn-shop' );
			$agn_checkout         = $params->get_option( 'agn-checkout' );
			$agn_single_product   = $params->get_option( 'agn-single-product' );
			$agn_product_category = $params->get_option( 'agn-product-category' );
			$agn_product_tag      = $params->get_option( 'agn-product-tag' );
			$detect_mobile        = $params->get_option( 'detect-mobile' );
			$show_at_order_bottom = $params->get_option( 'show_at_order_bottom' );
			if ( $show_at_order_bottom && ( is_checkout() || is_cart() || ( is_single() && $params->get_option( 'show_single_product' ) ) ) ) {
				return;
			}

			// Detect display on mobile or not
			$detect_mb = new WFSPB_Mobile_Detect();
			if ( $detect_mb->isMobile() ) {
				if ( $detect_mobile == 0 ) {
					return false;
				}
			}

			if ( $agn_homepage ) {
				if ( is_front_page() ) {
					return;
				}

			}

			if ( $agn_cart ) {
				if ( is_cart() ) {
					return;
				}
			}

			if ( $agn_shop ) {
				if ( is_shop() ) {
					return;
				}
			}

			if ( $agn_checkout ) {
				if ( is_checkout() ) {
					return;
				}
			}

			if ( $agn_single_product ) {
				if ( is_product() ) {
					return;
				}
			}

			if ( $agn_product_category ) {
				if ( is_product_category() ) {
					return;
				}
			}

			if ( $agn_product_tag ) {
				if ( is_product_tag() ) {
					return;
				}
			}

			if ( $conditional_tags ) {
				if ( stristr( $conditional_tags, "return" ) === false ) {
					$conditional_tags = "return (" . $conditional_tags . ");";
				}
				if ( eval( $conditional_tags ) ) {
					return;
				}
			}

			if ( $params->check_woo_shipping_zone() ) {
				echo $this->show_bar();
			}

		}
	}

	public function get_message( $arg ) {
		$params  = $this->settings;
		$message = $params->get_option( $arg );
		if ( is_array( $message ) ) {
			$lang    = function_exists( 'wpml_get_current_language' ) ? wpml_get_current_language() : 'default';
			$message = $message[ $lang ];
		}

		return $message;
	}

	public function show_bar() {
		$params            = $this->settings;
		$message_purchased = $this->get_message( 'message-purchased' );
		$announce_system   = $this->get_message( 'announce-system' );
		$message_success   = $this->get_message( 'message-success' );
		$message_error     = $this->get_message( 'message-error' );
		$close_message     = $params->get_option( 'close-message' );
		$default_zone      = $params->get_option( 'default-zone' );
		$detect_ip         = $params->get_option( 'detect-ip' );
		$initial_delay     = $params->get_option( 'initial-delay' );
		$position          = $params->get_option( 'position' );
		$enable_progress   = $params->get_option( 'enable-progress' );
		$progress_effect   = $params->get_option( 'progress_effect' );

		/*Time display bar*/
		$time_to_disappear  = $params->get_option( 'time-to-disappear' );
		$set_time_disappear = $params->get_option( 'set-time-disappear' );
		$show_giftbox       = $params->get_option( 'show-giftbox' );

		if ( $position == 0 ) {
			$class_pos = 'top_bar';
		} else {
			$class_pos = 'bottom_bar';
		}

		$announce_min_amount = '{min_amount}';

		$key          = array(
			'{total_amounts}',
			'{cart_amount}',
			'{min_amount}',
			'{missing_amount}'
		);
		$key_msgerror = array(
			'{missing_amount}',
			'{shopping}'
		);

		$shopping = '<a class="button" href="' . get_permalink( get_option( 'woocommerce_shop_page_id' ) ) . '">' . __( 'Shopping', 'woocommerce-free-shipping-bar' ) . '</a>';
		$checkout = '<a href="' . wc_get_checkout_url() . '" title="' . esc_html__( 'Checkout', 'woocommerce-free-shipping-bar' ) . '">' . esc_html__( 'Checkout', 'woocommerce-free-shipping-bar' ) . '</a>';

		$message_ss = str_replace( '{checkout_page}', $checkout, '<div id="wfspb-main-content">' . strip_tags( $message_success ) . '</div>' );
		$total      = WC()->cart->get_displayed_subtotal();

		if ( WC()->cart->display_prices_including_tax() ) {
			$total = round( $total - ( WC()->cart->get_discount_total() + WC()->cart->get_discount_tax() ), wc_get_price_decimals() );
		} else {
			$total = round( $total - WC()->cart->get_discount_total(), wc_get_price_decimals() );
		}

		$cart_amount = WC()->cart->cart_contents_count;

		$customer = WC()->session->get( 'customer' );
		$country  = isset( $customer['shipping_country'] ) ? $customer['shipping_country'] : '';
		$state    = isset( $customer['shipping_state'] ) ? $customer['shipping_state'] : '';

		$postcode = isset( $customer['shipping_postcode'] ) ? $customer['shipping_postcode'] : '';
		if ( $country ) {
			$order_min_amount = $params->detect_ip( $country, $state, $postcode );
			if ( ! $order_min_amount && $default_zone ) {
				$order_min_amount = $this->settings->toInt( $this->settings->get_min_amount( $default_zone ) );
			}
		} else if ( $detect_ip ) {
			$order_min_amount = $params->detect_ip();
		} elseif ( $default_zone ) {
			$order_min_amount = $params->get_min_amount( $default_zone );
		} else {
			$order_min_amount = $params->get_shipping_min_amount();
		}
		/**
		 * Check If min amount is empty
		 */
		if ( ! $order_min_amount ) {
			return;
		}

		if ( is_checkout() ) {
			if ( $total < $order_min_amount ) {
				$missing_amount   = $order_min_amount - $total;
				$missing_amount_r = $missing_amount;
				if ( ! wc()->cart->display_prices_including_tax() ) {

					if ( 'incl' !== get_option( 'woocommerce_tax_display_shop' ) ) {

						if ( ! wc_prices_include_tax() ) {

							$missing_amount_r = $params->real_amount( $missing_amount );
						}

					}
				}

				$msgerror_replaced = array( wc_price( $missing_amount_r ), $shopping );
				$message           = str_replace( $key_msgerror, $msgerror_replaced, '<div id="wfspb-main-content">' . strip_tags( $message_error ) . '</div>' );
			} else {
				$message = $message_ss;
			}
		} else {
			if ( $total < $order_min_amount ) {

				$missing_amount = $order_min_amount - $total;

				$cart_amount1 = '<b id="current-quantity">' . $cart_amount . '</b>';
				$order_mins   = '<b id="wfspb_min_order_amount">' . wc_price( $order_min_amount ) . '</b>';

				$total_amount = '<b id="wfspb-current-amout">' . wc_price( $total ) . '</b>';

				if ( is_cart() ) {
					if ( wc()->cart->display_prices_including_tax() ) {
						$missing_amount1 = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount ) . '</b>';
					} else {
						if ( 'incl' === get_option( 'woocommerce_tax_display_shop' ) ) {
							$missing_amount1 = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount ) . '</b>';

						} else {
							if ( wc_prices_include_tax() ) {
								$missing_amount1 = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount ) . '</b>';
							} else {
								$missing_amount_r = $params->real_amount( $missing_amount );
								$missing_amount1  = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount_r ) . '</b>';
							}

						}
					}
				} else {
					if ( 'incl' === get_option( 'woocommerce_tax_display_shop' ) ) {
						if ( wc()->cart->display_prices_including_tax() ) {
							$missing_amount1 = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount ) . '</b>';
						} else {
							$missing_amount_r = $params->get_price_including_tax( $missing_amount );
							$missing_amount1  = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount_r ) . esc_html__( '(incl. tax)', 'woocommerce-free-shipping-bar' ) . '</b>';
						}

					} else {
						if ( wc_prices_include_tax() ) {
							$missing_amount1 = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount ) . '</b>';
						} else {
							$missing_amount_r = $params->real_amount( $missing_amount );
							$missing_amount1  = '<b id="wfspb_missing_amount">' . wc_price( $missing_amount_r ) . '</b>';
						}

					}
				}

				$replaced = array(
					$total_amount,
					$cart_amount1,
					$order_mins,
					$missing_amount1
				);
				$message  = str_replace( $key, $replaced, '<div id="wfspb-main-content">' . strip_tags( $message_purchased ) . '</div>' );
			} else {
				$message = $message_ss;
			}
		}
		if ( $total ) {
			$class_pos .= ' has_items';
		}
		ob_start(); ?>

        <div id="wfspb-top-bar" data-initial-delay="<?php echo esc_attr( $initial_delay ) ?>"
             class="displaying customized <?php echo esc_attr( $class_pos ) ?>" style="<?php if ( ! is_checkout() ) {
			echo 'display: none;';
		} ?>"
			<?php if ( $time_to_disappear && $set_time_disappear ) {
				echo 'data-time-disappear="' . $set_time_disappear . '"';
			} ?> >
			<?php
			if ( $total == 0 ) {
				echo $message = str_replace( $announce_min_amount, wc_price( $order_min_amount ), '<div id="wfspb-main-content">' . strip_tags( $announce_system ) . '</div>' );
			} else {
				echo $message;
			}

			if ( $enable_progress ) {
				if ( $order_min_amount == 0 ) {
					$current_percent = $total * 100;
				} else {
					$current_percent = ( $total * 100 ) / $order_min_amount;
				}
				$class = array();
				if ( ! $total || $current_percent >= 100 ) {
					$class[] = 'wfsb-hidden';
				}
				if ( $progress_effect ) {
					$class[] = 'wfsb-effect-' . $progress_effect;
				}

				?>
                <div id="wfspb-progress" class="<?php echo esc_attr( implode( ' ', $class ) ) ?>">
                    <div id="wfspb-current-progress"
                         style="<?php echo intval( $current_percent ) > 0 ? 'width:' . $current_percent . '%' : '' ?>">
                        <div id="wfspb-label"><?php echo round( $current_percent, 0 ); ?>%</div>
                    </div>
                </div>
				<?php
			}
			if ( $close_message == 1 ) {
				echo '<div class="" id="wfspb-close"></div>';
			} ?>
        </div>
		<?php
		$class = $this->settings->get_option( 'gift_icon' ) ? 'wfspb-custom-image' : '';

		if ( $show_giftbox == 0 ) {
			return ob_get_clean();
		} ?>
        <div class="wfspb-gift-box <?php echo esc_attr( $class ); ?>"
             data-display="<?php echo esc_attr( $show_giftbox ); ?>">
			<?php if ( $this->settings->get_option( 'gift_icon' ) ) {
				$image_id = $this->settings->get_option( 'custom_icon' );
				if ( $image_id ) {
					echo wp_get_attachment_image( $image_id, 'full', false );
				}

			} else { ?>
                <img src="<?php echo esc_url( WFSPB_SHIPPING_IMAGES . 'free-delivery.png' ) ?>"/>
			<?php } ?>
        </div>

		<?php return ob_get_clean();
	}
}

new WFSPB_FrontEnd();